Package: opencis
Type: Package
Title: Import Data from Spanish Sociological Research Center (CIS)
Version: 0.1.1
Authors@R: c(
    person("Héctor", "Meleiro", email = "hmeleiros@gmail.com", role = c("aut", "cre"))
  )
Description: Search and import data directly to R from the Spanish Sociological
    Research Center (CIS) <https://www.cis.es/inicio>. The CIS is a public
    institution that conducts electoral and sociological research studies on the
    Spanish society. The CIS has a large database of surveys that can be
    accessed through its website. The package includes functions to search for
    surveys, survey questions and timeseries, and import the data directly to R.
License: GPL (>= 3)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
Depends: R (>= 3.5.0)
Imports: httr (>= 1.4.7), tibble (>= 3.0.0), purrr (>= 1.0.0), haven
        (>= 2.5.3), magrittr (>= 2.0.0), rvest (>= 1.0.0), stringr (>=
        1.0.0), memoise (>= 2.0.0)
URL: https://opencis.spainelectoralproject.com,
        https://CRAN.R-project.org/package=opencis,
        https://github.com/hmeleiro/opencis
BugReports: https://github.com/hmeleiro/opencis/issues
Suggests: knitr, testthat (>= 3.0.0), rmarkdown
VignetteBuilder: knitr
Config/Needs/website: hmeleiro/spainelectoraltheme
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-12 09:12:23 UTC; hmele
Author: Héctor Meleiro [aut, cre]
Maintainer: Héctor Meleiro <hmeleiros@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-12 18:40:25 UTC
Built: R 4.6.0; ; 2026-05-12 19:54:28 UTC; unix
