# Generated by roxygen2: do not edit by hand

export(browse_pdf)
export(clear_cache)
export(download_study)
export(get_data_dictionary)
export(get_metadata)
export(read_cis)
export(search_all_cis)
export(search_cis)
importFrom(haven,read_sav)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,modify_url)
importFrom(httr,status_code)
importFrom(httr,stop_for_status)
importFrom(httr,write_disk)
importFrom(magrittr,"%>%")
importFrom(memoise,forget)
importFrom(memoise,memoise)
importFrom(purrr,list_rbind)
importFrom(purrr,map)
importFrom(rvest,html_attr)
importFrom(rvest,html_element)
importFrom(rvest,html_elements)
importFrom(rvest,html_text)
importFrom(stringr,str_extract_all)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(utils,browseURL)
importFrom(utils,unzip)
