% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/search.R
\name{cis_catalog_url_date}
\alias{cis_catalog_url_date}
\title{Build CIS catalog URL with date range}
\usage{
cis_catalog_url_date(
  start = 1,
  q = "",
  from = NULL,
  to = NULL,
  sort = "relevance",
  catalogo = "estudio",
  ...
)
}
\arguments{
\item{start}{Integer. The starting page for the search results. Default is 1, iterate to get more results.}

\item{q}{String. The search query. Default is an empty string.}

\item{from}{Date or NULL. The start date for filtering results. Default is NULL}

\item{to}{Date or NULL. The end date for filtering results. Default is NULL.}

\item{sort}{String. The sorting order for the results ("publishDate-", "publishDate+", "relevance").
Default is "relevance".}

\item{catalogo}{String. The catalog type ("estudio", "pregunta", "serie"). Default is "estudio".}

\item{...}{Additional parameters (not used).}
}
\value{
A string representing the constructed URL.
}
\description{
Constructs a URL for querying the CIS catalog with optional date range filters.
}
\keyword{internal}
