% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zzz.R
\name{clear_cache}
\alias{clear_cache}
\title{Clear the opencis session cache}
\usage{
clear_cache()
}
\value{
\code{NULL} invisibly.
}
\description{
Clears the in-memory cache used by \code{\link{search_cis}} and
\code{\link{read_cis}}. Call this when you want to force fresh data
to be retrieved from the CIS server within the same R session.
}
