% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{list_file_paths}
\alias{list_file_paths}
\title{List file paths inside a ZIP archive}
\usage{
list_file_paths(zip_file, type = NULL)
}
\arguments{
\item{zip_file}{A string with the path to the ZIP file.}

\item{type}{A string with the file extension to filter by (e.g. \code{"sav"}, \code{"pdf"}).
If \code{NULL} (default), all files are returned.}
}
\value{
A data.frame with the files in the ZIP archive.
}
\description{
Returns a data.frame with the files contained in a ZIP archive,
optionally filtered by file extension.
}
\keyword{internal}
